@@ -10,10 +10,10 @@ Fast inference for Generalized Linear Mixed Models.
 from __future__ import absolute_import as _
 
 from . import cov, ggp, glmm, gp, lik, link, lmm, mean, random, util
-from ._test import test
+from .testit import test
 
 __name__ = "glimix-core"
-__version__ = "1.2.25"
+__version__ = "1.2.26"
 __author__ = "Danilo Horta"
 __author_email__ = "horta@ebi.ac.uk"
 
