@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, unicode_literals
 
 import logging
+from copy import deepcopy
 from math import fsum
 
 from numpy import dot, empty, inf, isfinite, log, maximum, sqrt, zeros
@@ -13,7 +14,7 @@ from .site import Site
 
 MAX_ITERS = 100
 RTOL = epsilon.small * 1000
-ATOL = epsilon.small * 1000
+ATOL = epsilon.small
 
 
 def ldot(A, B):
@@ -71,6 +72,59 @@ class EP(object):  # pylint: disable=R0903
         }
 
         self._need_params_update = True
+        self._cache = dict(lml=None, grad=None)
+
+    @property
+    def site(self):
+        return self._site
+
+    @property
+    def psite(self):
+        return self._psite
+
+    @property
+    def cav(self):
+        return self._cav
+
+    @property
+    def posterior(self):
+        return self._posterior
+
+    @property
+    def moments(self):
+        return self._moments
+
+    @property
+    def cache(self):
+        return self._cache
+
+    @cache.setter
+    def cache(self, v):
+        self._cache = v
+
+    @property
+    def need_params_update(self):
+        return self._need_params_update
+
+    @need_params_update.setter
+    def need_params_update(self, v):
+        self._need_params_update = v
+
+    def _copy_to(self, to):
+        self._site.copy_to(to.site)
+        self._psite.copy_to(to.psite)
+
+        to.cav['tau'] = self._cav['tau'].copy()
+        to.cav['eta'] = self._cav['eta'].copy()
+
+        self._posterior.copy_to(to.posterior)
+
+        to.moments['log_zeroth'][:] = self._moments['log_zeroth']
+        to.moments['mean'][:] = self._moments['mean']
+        to.moments['variance'][:] = self._moments['variance']
+
+        to.need_params_update = self._need_params_update
+        to.cache = deepcopy(self._cache)
 
     def _compute_moments(self):
         r"""Compute zero-th, first, and second moments.
@@ -84,8 +138,13 @@ class EP(object):  # pylint: disable=R0903
         self._posterior.mean = mean
         self._posterior.cov = cov
         self._need_params_update = True
+        self._cache['lml'] = None
+        self._cache['grad'] = None
 
     def _lml(self):
+        if self._cache['lml'] is not None:
+            return self._cache['lml']
+
         self._params_update()
 
         L = self._posterior.L()
@@ -119,6 +178,7 @@ class EP(object):  # pylint: disable=R0903
         if not isfinite(lml):
             raise ValueError("LML should not be %f." % lml)
 
+        self._cache['lml'] = lml
         return lml
 
     def _lml_derivative_over_mean(self, dm):
@@ -183,7 +243,9 @@ class EP(object):  # pylint: disable=R0903
 
             self._posterior.update()
 
-            tol = RTOL * norm(self._psite.tau) + ATOL
+            n0 = norm(self._psite.tau)
+            n1 = norm(self._cav['tau'])
+            tol = RTOL * sqrt(n0 * n1) + ATOL
             i += 1
 
         if i == MAX_ITERS:
