@@ -5,20 +5,22 @@ from glimix_core.cov import EyeCov, LinearCov, SumCov
 from glimix_core.mean import OffsetMean
 
 
+def nsamples():
+    return 30
+
+
 def offset_mean():
-    N = 100
     mean = OffsetMean()
     mean.offset = 0.5
-    mean.set_data(arange(N), purpose='sample')
-    mean.set_data(arange(N), purpose='learn')
+    mean.set_data(arange(nsamples()), purpose='sample')
+    mean.set_data(arange(nsamples()), purpose='learn')
 
     return mean
 
 
 def linear_eye_cov():
     random = RandomState(458)
-    N = 100
-    X = random.randn(N, N + 1)
+    X = random.randn(nsamples(), nsamples() + 1)
     X -= X.mean(0)
     X /= X.std(0)
     X /= sqrt(X.shape[1])
@@ -30,7 +32,8 @@ def linear_eye_cov():
 
     cov_right = EyeCov()
     cov_right.scale = 1.0
-    cov_right.set_data((arange(N), arange(N)), purpose='sample')
-    cov_right.set_data((arange(N), arange(N)), purpose='learn')
+    n = nsamples()
+    cov_right.set_data((arange(n), arange(n)), purpose='sample')
+    cov_right.set_data((arange(n), arange(n)), purpose='learn')
 
     return SumCov([cov_left, cov_right])
